@@ -48,7 +48,10 @@ for p1 in dir:
     if i<len(dir)-2:
         currentdir += p1 + '/'
         i+=1
-workdir = os.getcwd().replace('\\', '/')
+
+if "win" in platform:
+    workdir = os.getcwd().replace('\\', '/')
+
 settings_file = currentdir + 'ncfiles/settings_file.cfg'
 default_settings = {'Pymol_location': pymol_exe ,
                     'Clustalw_location': clustalw_exe,
@@ -68,17 +71,21 @@ else:
     sg.popup_quick_message('No settings file found. Creating one with default values...',
                            keep_on_top=True, background_color='red', text_color='white')
     settings = default_settings
-
+    with open(settings_file, "w+") as s:
+        json.dump(default_settings, s)
 
 
 def main():
-    scrpath = os.path.realpath(__file__).split('\\')
+    if 'win' in platform:
+        scrpath = os.path.realpath(__file__).split('\\')
+    else:
+        scrpath = os.path.realpath(__file__).split('/')
     imgpath = ''
     for i in scrpath:
         if i != 'GUI.py':
-            imgpath += str(i) + '\\'
+            imgpath += str(i) + '/'
     img = imgpath + 'ncfiles/CapiPy.png'
-    sg.theme(default_settings['theme'])
+    sg.theme(settings['theme'])
 
     layout_main = [[sg.Text('Welcome to CapiPy!', font =('Helvetica', 20, 'bold'))],
                    [sg.Button('1. Blast and Modeller', font =('Helvetica', 12), size=(30, 3))],
