@@ -38,8 +38,11 @@ def main(folder_answer, folder_name, pdbfile, active_site):
         try:
             shutil.copy("../Blast&Modeller/" + str(pdbfile), './query.pdb')
         except BaseException:
-            print('Cannot find the pdb file. Check again the name!')
-            quit()
+            try:
+                shutil.copy(pdbfile, './query.pdb')
+            except BaseException:
+                print('Cannot find the pdb file. Check again the name!')
+                quit()
     elif folder_answer == 'YES':
         os.mkdir(working_directory)
         os.chdir(working_directory)
